<?php

namespace Bixo\ImportExport\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Exception;
use Bixo\ImportExport\Http\Requests\ImportExportActionsRequest;
use Bixo\ImportExport\Actions\ImportExportActions;

/**
 * Admin web controller class.
 */
class ImportExportActionsController extends BaseController
{

    /**
     * Action controller function for import_export.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(ImportExportActionsRequest $request, $action)
    {
        try {
            $import_export = ImportExportActions::run($request, $action);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('import_export::import_export.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('import_export/import_export/' . $action))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('import_export/import_export/' . $action))
                ->redirect();
        }
    }
}
