<?php
namespace Bixo\ImportExport\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\ImportExport\Events\ImportExportAction as ImportExportActionEvent;
use Bixo\ImportExport\Models\ImportExport;

class ImportExportAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $import_export;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param ImportExportActionEvent $import_export
     */
    public function __construct(ImportExportActionEvent $import_export)
    {
        $this->action = $event->action;
        $this->import_export = $import_export;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('ImportExport Approved - ' . config('app.name'))
            ->view('import_export::import_export.email.action', ['data' => $this->import_export]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
