<?php

namespace Bixo\ImportExport\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\ImportExport\Models\ImportExport;

class ImportExportPolicy
{

    use ImportExportAction;
    use ImportExportExim;
    use ImportExportReport;
    use ImportExportWorkflow;

    /**
     * Determine if the given user can view the import_export.
     *
     * @param Authenticatable $user
     * @param ImportExport $import_export
     *
     * @return bool
     */
    public function view(Authenticatable $user, ImportExport $import_export)
    {
        if ($authUser->canDo('import_export.import_export.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $import_export->is_owner;
    }

    /**
     * Determine if the given user can create a import_export.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('import_export.import_export.create');
    }

    /**
     * Determine if the given user can update the given import_export.
     *
     * @param Authenticatable $user
     * @param ImportExport $import_export
     *
     * @return bool
     */
    public function update(Authenticatable $user, ImportExport $import_export)
    {
        if ($user->canDo('import_export.import_export.edit') && $user->isAdmin()) {
            return true;
        }

        return $import_export->is_owner;
    }

    /**
     * Determine if the given user can delete the given import_export.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, ImportExport $import_export)
    {
        return $import_export->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
